@@ -616,9 +616,9 @@ class _tensor_py_operators:
         except TypeError:
             # This prevents accidental iteration via sum(self)
             raise TypeError(
-                "TensorType does not support iteration. "
-                "Maybe you are using builtins.sum instead of "
-                "pytensor.tensor.math.sum? (Maybe .max?)"
+                "TensorType does not support iteration.\n"
+                "\tDid you pass a PyTensor variable to a function that expects a list?\n"
+                "\tMaybe you are using builtins.sum instead of pytensor.tensor.sum?"
             )
 
     @property
@@ -1023,21 +1023,6 @@ class TensorConstant(TensorVariable, Constant[_TensorTypeType]):
 
         Constant.__init__(self, new_type, data, name)
 
-    def __str__(self):
-        unique_val = get_unique_value(self)
-        if unique_val is not None:
-            val = f"{self.data.shape} of {unique_val}"
-        else:
-            val = f"{self.data}"
-        if len(val) > 20:
-            val = val[:10] + ".." + val[-10:]
-
-        if self.name is not None:
-            name = self.name
-        else:
-            name = "TensorConstant"
-        return f"{name}{{{val}}}"
-
     def signature(self):
         return TensorConstantSignature((self.type, self.data))
 
